colour.constants.codata — Colour 0.3.0 documentation

# Source code for colour.constants.codata

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    """
    Fundamental Physical Constants
    ==============================

    Defines various constants from recommended values by the Committee on Data for
    Science and Technology (CODATA).
    """

    from __future__ import division, unicode_literals

    __author__ = 'Colour Developers'
    __copyright__ = 'Copyright (C) 2013 - 2014 - Colour Developers'
    __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
    __maintainer__ = 'Colour Developers'
    __email__ = 'colour-science@googlegroups.com'
    __status__ = 'Production'

    __all__ = ['AVOGADRO_CONSTANT',
               'BOLTZMANN_CONSTANT',
               'LIGHT_SPEED',
               'PLANCK_CONSTANT']

    AVOGADRO_CONSTANT = 6.02214179e23
    """
    Avogadro constant.

    AVOGADRO_CONSTANT : numeric
    """

    BOLTZMANN_CONSTANT = 1.38065e-23
    """
    Boltzmann constant.

    BOLTZMANN_CONSTANT : numeric
    """

    LIGHT_SPEED = 299792458
    """
    Speed of light in vacuum.

    LIGHT_SPEED : numeric
    """

    PLANCK_CONSTANT = 6.62607e-34
    """
    Planck constant.

    PLANCK_CONSTANT : numeric
    """